==> core-1.8.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/ValidationResults.java <==
package software.amazon.awscdk.core;

/**
 * A collection of validation results.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-10T21:04:46.931Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.ValidationResults")
public class ValidationResults extends software.amazon.jsii.JsiiObject {

    protected ValidationResults(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ValidationResults(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ValidationResults(final java.util.List<software.amazon.awscdk.core.ValidationResult> results) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { results }));
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ValidationResults() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void collect(final software.amazon.awscdk.core.ValidationResult result) {
        this.jsiiCall("collect", Void.class, new Object[] { java.util.Objects.requireNonNull(result, "result is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String errorTreeList() {
        return this.jsiiCall("errorTreeList", java.lang.String.class);
    }

    /**
     * Wrap up all validation results into a single tree node.
     * 
     * If there are failures in the collection, add a message, otherwise
     * return a success.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.core.ValidationResult wrap(final java.lang.String message) {
        return this.jsiiCall("wrap", software.amazon.awscdk.core.ValidationResult.class, new Object[] { java.util.Objects.requireNonNull(message, "message is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.Boolean getIsSuccess() {
        return this.jsiiGet("isSuccess", java.lang.Boolean.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<software.amazon.awscdk.core.ValidationResult> getResults() {
        return this.jsiiGet("results", java.util.List.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setResults(final java.util.List<software.amazon.awscdk.core.ValidationResult> value) {
        this.jsiiSet("results", java.util.Objects.requireNonNull(value, "results is required"));
    }
}

==> core-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/core/ValidationResults.java <==
package software.amazon.awscdk.core;

/**
 * A collection of validation results.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:44:35.481Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.ValidationResults")
public class ValidationResults extends software.amazon.jsii.JsiiObject {

    protected ValidationResults(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ValidationResults(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param results
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ValidationResults(final java.util.List<software.amazon.awscdk.core.ValidationResult> results) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { results }));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ValidationResults() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this));
    }

    /**
     * @param result This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void collect(final software.amazon.awscdk.core.ValidationResult result) {
        this.jsiiCall("collect", Void.class, new Object[] { java.util.Objects.requireNonNull(result, "result is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String errorTreeList() {
        return this.jsiiCall("errorTreeList", java.lang.String.class);
    }

    /**
     * Wrap up all validation results into a single tree node.
     * 
     * If there are failures in the collection, add a message, otherwise
     * return a success.
     * 
     * @param message This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.core.ValidationResult wrap(final java.lang.String message) {
        return this.jsiiCall("wrap", software.amazon.awscdk.core.ValidationResult.class, new Object[] { java.util.Objects.requireNonNull(message, "message is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.Boolean getIsSuccess() {
        return this.jsiiGet("isSuccess", java.lang.Boolean.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<software.amazon.awscdk.core.ValidationResult> getResults() {
        return java.util.Collections.unmodifiableList(this.jsiiGet("results", java.util.List.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void setResults(final java.util.List<software.amazon.awscdk.core.ValidationResult> value) {
        this.jsiiSet("results", java.util.Objects.requireNonNull(value, "results is required"));
    }
}
